ConverterBallot
===============

.. toctree::

   converter_ballot
   converter_ballot_general
   converter_ballot_to_grades
   converter_ballot_to_levels
   converter_ballot_to_levels_interval
   converter_ballot_to_levels_list_non_numeric
   converter_ballot_to_levels_list_numeric
   converter_ballot_to_levels_range
   converter_ballot_to_order
   converter_ballot_to_plurality
   converter_ballot_to_strict_order
   converter_ballot_to_veto
